==> num_to_ordinal-0.0.1.tar.gz: num_to_ordinal-0.0.1/src/ToOrdinal.py <==


ordinal_es_o = ['Primero',
'Segundo',
'Tercero',
'Cuarto',
'Quinto',
'Sexto',
'Séptimo',
'Octavo',
'Noveno',
'Décimo',
'Undécimo',
'Duodécimo',
'Decimotercero',
'Decimocuarto',
'Decimoquinto',
'Decimosexto',
'Decimoséptimo',
'Decimoctavo',
'Decimonoveno',
'Vigésimo',
'Vigesimoprimero',
'Vigesimosegundo',
'Vigesimotercero',
'Vigesimocuarto',
'Vigesimoquinto',
'Vigesimosexto',
'Vigesimoséptimo',
'Vigesimoctavo',
'Vigesimonoveno',
'Trigésimo',
'Trigésimo primero',
'Trigésimo segundo',
'Trigésimo tercero',
'Trigésimo cuarto',
'Trigésimo quinto',
'Trigésimo sexto',
'Trigésimo séptimo',
'Trigésimo octavo',
'Trigésimo noveno',
'Cuadragésimo',
'Cuadragésimo primero',
'Cuadragésimo segundo',
'Cuadragésimo tercero',
'Cuadragésimo cuarto',
'Cuadragésimo quinto',
'Cuadragésimo sexto',
'Cuadragésimo séptimo',
'Cuadragésimo octavo',
'Cuadragésimo noveno',
'Quincuagésimo',
'Quincuagésimo primero',
'Quincuagésimo segundo',
'Quincuagésimo tercero',
'Quincuagésimo cuarto',
'Quincuagésimo quinto',
'Quincuagésimo sexto',
'Quincuagésimo séptimo',
'Quincuagésimo octavo',
'Quincuagésimo noveno',
'Sexagésimo',
'Sexagésimo primero',
'Sexagésimo segundo',
'Sexagésimo tercero',
'Sexagésimo cuarto',
'Sexagésimo quinto',
'Sexagésimo sexto',
'Sexagésimo séptimo',
'Sexagésimo octavo',
'Sexagésimo noveno',
'Septuagésimo',
'Septuagésimo primero',
'Septuagésimo segundo',
'Septuagésimo tercero',
'Septuagésimo cuarto',
'Septuagésimo quinto',
'Septuagésimo sexto',
'Septuagésimo séptimo',
'Septuagésimo octavo',
'Septuagésimo noveno',
'Octogésimo',
'Octogésimo primero',
'Octogésimo segundo',
'Octogésimo tercero',
'Octogésimo cuarto',
'Octogésimo quinto',
'Octogésimo sexto',
'Octogésimo séptimo',
'Octogésimo octavo',
'Octogésimo noveno',
'Nonagésimo',
'Nonagésimo primero',
'Nonagésimo segundo',
'Nonagésimo tercero',
'Nonagésimo cuarto',
'Nonagésimo quinto',
'Nonagésimo sexto',
'Nonagésimo séptimo',
'Nonagésimo octavo',
'Nonagésimo noveno',
'Centésimo']

ordinal_es_a = [' Primera',
' Segunda',
' Tercera',
' Cuarta',
' Quinta',
' Sexta',
' Séptima',
' Octava',
' Novena',
' Décima',
' Undécima',
' Duodécima',
' Decimotercera',
' Decimocuarta',
' Decimoquinta',
' Decimosexta',
' Decimoséptima',
' Decimoctava',
' Decimonovena',
' Vigésima',
'Vigesimoprimera',
' Vigesimosegunda',
' Vigesimotercera',
' Vigesimocuarta',
' Vigesimoquinta',
' Vigesimosexta',
' Vigesimoséptima',
' Vigesimoctava',
' Vigesimonovena',
' Trigésima',
' Trigésima Primera',
' Trigésima Segunda',
' Trigésima Tercera',
' Trigésima Cuarta',
' Trigésima Quinta',
' Trigésima Sexta',
' Trigésima Séptima',
' Trigésima Octava',
' Trigésima Novena',
' Cuadragésima',
' Cuadragésima Primera',
' Cuadragésima Segunda',
' Cuadragésima Tercera',
' Cuadragésima Cuarta',
' Cuadragésima Quinta',
' Cuadragésima Sexta',
' Cuadragésima Séptimo',
' Cuadragésima Octava',
' Cuadragésima Novena',
' Quincuagésima',
' Quincuagésima Primera',
' Quincuagésima Segunda',
' Quincuagésima Tercera',
' Quincuagésima Cuarta',
' Quincuagésima Quinta',
' Quincuagésima Sexta',
' Quincuagésima Séptima',
' Quincuagésima Octava',
' Quincuagésima Novena',
' Sexagésima',
' Sexagésima Primera',
' Sexagésima Segunda',
' Sexagésima Tercera',
' Sexagésima Cuarta',
' Sexagésima Quinta',
' Sexagésima Sexta',
' Sexagésima Séptima',
' Sexagésima Octava',
' Sexagésima Novena',
' Septuagésima',
' Septuagésima Primera',
' Septuagésima Segunda',
' Septuagésima Tercera',
' Septuagésima Cuarta',
' Septuagésima Quinta',
' Septuagésima Sexta',
' Septuagésima Séptima',
' Septuagésima Octava',
' Septuagésima Novena',
' Octogésima',
' Octogésima Primera',
' Octogésima Segunda',
' Octogésima Tercera',
' Octogésima Cuarta',
' Octogésima Quinta',
' Octogésima Sexta',
' Octogésima Séptima',
' Octogésima Octava',
' Octogésima Novena',
' Nonagésima',
' Nonagésima Primera',
' Nonagésima Segunda',
' Nonagésima Tercera',
' Nonagésima Cuarta',
' Nonagésima Quinta',
' Nonagésima Sexta',
' Nonagésima Séptima',
' Nonagésima Octava',
' Nonagésima Novena',
' Centésima']

ordinals_en = [' First',
' Second',
' Third',
' Fourth',
' Fifth',
' Sixth',
' Seventh',
' Eighth',
' Ninth',
' Tenth',
' Eleventh',
' Twelfth',
' Thirteenth',
' Fourteenth',
' Fifteenth',
' Sixteenth',
' Seventeenth',
' Eighteenth',
' Nineteenth',
' Twentieth',
' Twenty-First',
' Twenty-Second',
' Twenty-Third',
' Twenty-Fourth',
' Twenty-Fifth',
' Twenty-Sixth',
' Twenty-Seventh',
' Twenty-Eighth',
' Twenty-Ninth',
' Thirtieth',
' Thirty-First',
' Thirty-Second',
' Thirty-Third',
' Thirty-Fourth',
' Thirty-Fifth',
' Thirty-Sixth',
' Thirty-Seventh',
' Thirty-Eighth',
' Thirty-Ninth',
' Fortieth',
' Forty-First',
' Forty-Second',
' Forty-Third',
' Forty-Fourth',
' Forty-Fifth',
' Forty-Sixth',
' Forty-Seventh',
' Forty-Eighth',
' Forty-Ninth',
' Fiftieth',
' Fifty-First',
' Fifty-Second',
' Fifty-Third',
' Fifty-Fourth',
' Fifty-Fifth',
' Fifty-Sixth',
' Fifty-Seventh',
' Fifty-Eighth',
' Fifty-Ninth',
' Sixtieth',
' Sixty-First',
' Sixty-Second',
' Sixty-Third',
' Sixty-Fourth',
' Sixty-Fifth',
' Sixty-Sixth',
' Sixty-Seventh',
' Sixty-Eighth',
' Sixty-Ninth',
' Seventieth',
' Seventy-First',
' Seventy-Second',
' Seventy-Third',
' Seventy-Fourth',
' Seventy-Fifth',
' Seventy-Sixth',
' Seventy-Seventh',
' Seventy-Eighth',
' Seventy-Ninth',
' Eightieth',
' Eighty-First',
' Eighty-Second',
' Eighty-Third',
' Eighty-Fourth',
' Eighty-Fifth',
' Eighty-Sixth',
' Eighty-Seventh',
' Eighty-Eighth',
' Eighty-Ninth',
' Ninetieth',
' Ninety-First',
' Ninety-Second',
' Ninety-Third',
' Ninety-Fourth',
' Ninety-Fifth',
' Ninety-Sixth',
' Ninety-Seventh',
' Ninety-Eighth',
' Ninety-Ninth',
' Hundredth']


def get_ordinal(lang = 'es',type = 'a',num):
    if num < 100 and num != 0:
        if lang == 'es':
            if type == 'a':
                return ordinal_es_a[num - 1]
            else:
                return ordinal_es_o[num - 1]
        else:
            return ordinals_en[num - 1]

==> num_to_ordinal-0.0.2.tar.gz: num_to_ordinal-0.0.2/src/ToOrdinal.py <==


ordinal_es_o = ['Primero',
'Segundo',
'Tercero',
'Cuarto',
'Quinto',
'Sexto',
'Séptimo',
'Octavo',
'Noveno',
'Décimo',
'Undécimo',
'Duodécimo',
'Decimotercero',
'Decimocuarto',
'Decimoquinto',
'Decimosexto',
'Decimoséptimo',
'Decimoctavo',
'Decimonoveno',
'Vigésimo',
'Vigesimoprimero',
'Vigesimosegundo',
'Vigesimotercero',
'Vigesimocuarto',
'Vigesimoquinto',
'Vigesimosexto',
'Vigesimoséptimo',
'Vigesimoctavo',
'Vigesimonoveno',
'Trigésimo',
'Trigésimo primero',
'Trigésimo segundo',
'Trigésimo tercero',
'Trigésimo cuarto',
'Trigésimo quinto',
'Trigésimo sexto',
'Trigésimo séptimo',
'Trigésimo octavo',
'Trigésimo noveno',
'Cuadragésimo',
'Cuadragésimo primero',
'Cuadragésimo segundo',
'Cuadragésimo tercero',
'Cuadragésimo cuarto',
'Cuadragésimo quinto',
'Cuadragésimo sexto',
'Cuadragésimo séptimo',
'Cuadragésimo octavo',
'Cuadragésimo noveno',
'Quincuagésimo',
'Quincuagésimo primero',
'Quincuagésimo segundo',
'Quincuagésimo tercero',
'Quincuagésimo cuarto',
'Quincuagésimo quinto',
'Quincuagésimo sexto',
'Quincuagésimo séptimo',
'Quincuagésimo octavo',
'Quincuagésimo noveno',
'Sexagésimo',
'Sexagésimo primero',
'Sexagésimo segundo',
'Sexagésimo tercero',
'Sexagésimo cuarto',
'Sexagésimo quinto',
'Sexagésimo sexto',
'Sexagésimo séptimo',
'Sexagésimo octavo',
'Sexagésimo noveno',
'Septuagésimo',
'Septuagésimo primero',
'Septuagésimo segundo',
'Septuagésimo tercero',
'Septuagésimo cuarto',
'Septuagésimo quinto',
'Septuagésimo sexto',
'Septuagésimo séptimo',
'Septuagésimo octavo',
'Septuagésimo noveno',
'Octogésimo',
'Octogésimo primero',
'Octogésimo segundo',
'Octogésimo tercero',
'Octogésimo cuarto',
'Octogésimo quinto',
'Octogésimo sexto',
'Octogésimo séptimo',
'Octogésimo octavo',
'Octogésimo noveno',
'Nonagésimo',
'Nonagésimo primero',
'Nonagésimo segundo',
'Nonagésimo tercero',
'Nonagésimo cuarto',
'Nonagésimo quinto',
'Nonagésimo sexto',
'Nonagésimo séptimo',
'Nonagésimo octavo',
'Nonagésimo noveno',
'Centésimo']

ordinal_es_a = [' Primera',
' Segunda',
' Tercera',
' Cuarta',
' Quinta',
' Sexta',
' Séptima',
' Octava',
' Novena',
' Décima',
' Undécima',
' Duodécima',
' Decimotercera',
' Decimocuarta',
' Decimoquinta',
' Decimosexta',
' Decimoséptima',
' Decimoctava',
' Decimonovena',
' Vigésima',
'Vigesimoprimera',
' Vigesimosegunda',
' Vigesimotercera',
' Vigesimocuarta',
' Vigesimoquinta',
' Vigesimosexta',
' Vigesimoséptima',
' Vigesimoctava',
' Vigesimonovena',
' Trigésima',
' Trigésima Primera',
' Trigésima Segunda',
' Trigésima Tercera',
' Trigésima Cuarta',
' Trigésima Quinta',
' Trigésima Sexta',
' Trigésima Séptima',
' Trigésima Octava',
' Trigésima Novena',
' Cuadragésima',
' Cuadragésima Primera',
' Cuadragésima Segunda',
' Cuadragésima Tercera',
' Cuadragésima Cuarta',
' Cuadragésima Quinta',
' Cuadragésima Sexta',
' Cuadragésima Séptimo',
' Cuadragésima Octava',
' Cuadragésima Novena',
' Quincuagésima',
' Quincuagésima Primera',
' Quincuagésima Segunda',
' Quincuagésima Tercera',
' Quincuagésima Cuarta',
' Quincuagésima Quinta',
' Quincuagésima Sexta',
' Quincuagésima Séptima',
' Quincuagésima Octava',
' Quincuagésima Novena',
' Sexagésima',
' Sexagésima Primera',
' Sexagésima Segunda',
' Sexagésima Tercera',
' Sexagésima Cuarta',
' Sexagésima Quinta',
' Sexagésima Sexta',
' Sexagésima Séptima',
' Sexagésima Octava',
' Sexagésima Novena',
' Septuagésima',
' Septuagésima Primera',
' Septuagésima Segunda',
' Septuagésima Tercera',
' Septuagésima Cuarta',
' Septuagésima Quinta',
' Septuagésima Sexta',
' Septuagésima Séptima',
' Septuagésima Octava',
' Septuagésima Novena',
' Octogésima',
' Octogésima Primera',
' Octogésima Segunda',
' Octogésima Tercera',
' Octogésima Cuarta',
' Octogésima Quinta',
' Octogésima Sexta',
' Octogésima Séptima',
' Octogésima Octava',
' Octogésima Novena',
' Nonagésima',
' Nonagésima Primera',
' Nonagésima Segunda',
' Nonagésima Tercera',
' Nonagésima Cuarta',
' Nonagésima Quinta',
' Nonagésima Sexta',
' Nonagésima Séptima',
' Nonagésima Octava',
' Nonagésima Novena',
' Centésima']

ordinals_en = [' First',
' Second',
' Third',
' Fourth',
' Fifth',
' Sixth',
' Seventh',
' Eighth',
' Ninth',
' Tenth',
' Eleventh',
' Twelfth',
' Thirteenth',
' Fourteenth',
' Fifteenth',
' Sixteenth',
' Seventeenth',
' Eighteenth',
' Nineteenth',
' Twentieth',
' Twenty-First',
' Twenty-Second',
' Twenty-Third',
' Twenty-Fourth',
' Twenty-Fifth',
' Twenty-Sixth',
' Twenty-Seventh',
' Twenty-Eighth',
' Twenty-Ninth',
' Thirtieth',
' Thirty-First',
' Thirty-Second',
' Thirty-Third',
' Thirty-Fourth',
' Thirty-Fifth',
' Thirty-Sixth',
' Thirty-Seventh',
' Thirty-Eighth',
' Thirty-Ninth',
' Fortieth',
' Forty-First',
' Forty-Second',
' Forty-Third',
' Forty-Fourth',
' Forty-Fifth',
' Forty-Sixth',
' Forty-Seventh',
' Forty-Eighth',
' Forty-Ninth',
' Fiftieth',
' Fifty-First',
' Fifty-Second',
' Fifty-Third',
' Fifty-Fourth',
' Fifty-Fifth',
' Fifty-Sixth',
' Fifty-Seventh',
' Fifty-Eighth',
' Fifty-Ninth',
' Sixtieth',
' Sixty-First',
' Sixty-Second',
' Sixty-Third',
' Sixty-Fourth',
' Sixty-Fifth',
' Sixty-Sixth',
' Sixty-Seventh',
' Sixty-Eighth',
' Sixty-Ninth',
' Seventieth',
' Seventy-First',
' Seventy-Second',
' Seventy-Third',
' Seventy-Fourth',
' Seventy-Fifth',
' Seventy-Sixth',
' Seventy-Seventh',
' Seventy-Eighth',
' Seventy-Ninth',
' Eightieth',
' Eighty-First',
' Eighty-Second',
' Eighty-Third',
' Eighty-Fourth',
' Eighty-Fifth',
' Eighty-Sixth',
' Eighty-Seventh',
' Eighty-Eighth',
' Eighty-Ninth',
' Ninetieth',
' Ninety-First',
' Ninety-Second',
' Ninety-Third',
' Ninety-Fourth',
' Ninety-Fifth',
' Ninety-Sixth',
' Ninety-Seventh',
' Ninety-Eighth',
' Ninety-Ninth',
' Hundredth']


def get_ordinal(lang = 'es',type = 'a',num = 1):
    if num < 100 and num != 0:
        if lang == 'es':
            if type == 'a':
                return ordinal_es_a[num - 1]
            else:
                return ordinal_es_o[num - 1]
        else:
            return ordinals_en[num - 1]
